@@ -1,11 +1,11 @@
 /* -*-c-*- -------------- xmix_vm_handlers.c :
  * Implementation of the functions declared in xmix_vm_handlers.h
  * ------------------------------------------------------------------
- * Copyright (C) 2001, 2002, 2003, 2004, 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2003, 2004, 2006, 2007 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -286,10 +286,38 @@ cmd_compile_ (mix_vm_cmd_dispatcher_t *dis, const gchar *arg)
   else
     {
       gchar *cmd = g_strdup_printf (dis->assembler, arg);
+      gchar *errors = NULL;
+      gchar *output = NULL;
+      gint exit_status;
+      gboolean result;
+      GError *gerr = NULL;
+
       if (wants_logs_ (dis)) log_message_ (dis, cmd);
-      if (system (cmd) == EXIT_SUCCESS && wants_logs_ (dis))
-	log_message_ (dis, _("Successful compilation"));
+
+      result =
+        g_spawn_command_line_sync (cmd, &output, &errors, &exit_status, &gerr);
+
+      if (output)
+        {
+          log_message_ (dis, output);
+        }
+
+      if (errors != NULL)
+        {
+          log_message_ (dis, errors);
+        }
+      else if ((exit_status != 0) || !result)
+        {
+          log_error_ (dis, _("Compilation failed"));
+          if (gerr && gerr->message) log_error_ (dis, gerr->message);
+        }
+
+      if (gerr) g_free (gerr);
+      if (output) g_free (output);
+      if (errors) g_free (errors);
+
       g_free (cmd);
+
       return TRUE;
     }
 }
